@@ -10,8 +10,8 @@
 
 #include <KMime/KMimeMessage>
 
+#include <Akonadi/AddressAttribute>
 #include <Akonadi/Collection>
-#include <Akonadi/KMime/AddressAttribute>
 
 using namespace Akonadi;
 using namespace KMime;
@@ -22,9 +22,7 @@ ResourceSendJob::ResourceSendJob(Transport *transport, QObject *parent)
 {
 }
 
-ResourceSendJob::~ResourceSendJob()
-{
-}
+ResourceSendJob::~ResourceSendJob() = default;
 
 void ResourceSendJob::doStart()
 {
